@@ -73,13 +73,13 @@ class BlobTask(EOTask):
         self.blob_parameters = blob_parameters
 
     def _compute_blob(self, data):
-        result = np.zeros(data.shape, dtype=np.float)
+        result = np.zeros(data.shape, dtype=float)
         for time in range(data.shape[0]):
             for band in range(data.shape[-1]):
                 image = data[time, :, :, band]
                 res = np.asarray(self.blob_object(image, **self.blob_parameters))
-                x_coord = res[:, 0].astype(np.int)
-                y_coord = res[:, 1].astype(np.int)
+                x_coord = res[:, 0].astype(int)
+                y_coord = res[:, 1].astype(int)
                 radius = res[:, 2] * sqrt(2)
                 result[time, x_coord, y_coord, band] = radius
         return result
